/**********************************************************************************************************************
 * Copyright (c) Prophesee S.A.                                                                                       *
 *                                                                                                                    *
 * Licensed under the Apache License, Version 2.0 (the "License");                                                    *
 * you may not use this file except in compliance with the License.                                                   *
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0                                 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed   *
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.                      *
 * See the License for the specific language governing permissions and limitations under the License.                 *
 **********************************************************************************************************************/

#ifndef METAVISION_HAL_CCAM3_SINGLE_GEN3_H
#define METAVISION_HAL_CCAM3_SINGLE_GEN3_H

#include "tep_register_control_register_map.h"
#include "ccam2_system_monitor_trigger_ext_adc.h"
#include "gen3_sensor_if_register_map.h"
#include "system_config_register_map.h"
#include "fx3_host_if_register_map.h"
#include "imu_register_map.h"

//------------------------------------------------------------------------------------------------------------
// CCAM3
//------------------------------------------------------------------------------------------------------------

#define CCAM3_BASE_ADDR 0x00000000
#define CCAM3_LAST_ADDR 0x00001975
#define CCAM3_SIZE 0x00002000

//------------------------------------------------------------------------------------------------------------
// CCAM3_SYS_REG
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SYS_REG_BASE_ADDR 0x00000000
#define CCAM3_SYS_REG_LAST_ADDR 0x0000003C
#define CCAM3_SYS_REG_SIZE 0x00000040

#define CCAM3_ATIS_CONTROL_ADDR 0x00000000
#define CCAM3_ATIS_CONTROL_EN_VDDA_BIT_IDX 0
#define CCAM3_ATIS_CONTROL_EN_VDDA_WIDTH 1
#define CCAM3_ATIS_CONTROL_EN_VDDA_DEFAULT 0x00000000
#define CCAM3_ATIS_CONTROL_EN_VDDC_BIT_IDX 1
#define CCAM3_ATIS_CONTROL_EN_VDDC_WIDTH 1
#define CCAM3_ATIS_CONTROL_EN_VDDC_DEFAULT 0x00000000
#define CCAM3_ATIS_CONTROL_EN_VDDD_BIT_IDX 2
#define CCAM3_ATIS_CONTROL_EN_VDDD_WIDTH 1
#define CCAM3_ATIS_CONTROL_EN_VDDD_DEFAULT 0x00000000
#define CCAM3_ATIS_CONTROL_SENSOR_SOFT_RESET_BIT_IDX 3
#define CCAM3_ATIS_CONTROL_SENSOR_SOFT_RESET_WIDTH 1
#define CCAM3_ATIS_CONTROL_SENSOR_SOFT_RESET_DEFAULT 0x00000001
#define CCAM3_ATIS_CONTROL_IN_EVT_NO_BLOCKING_MODE_BIT_IDX 4
#define CCAM3_ATIS_CONTROL_IN_EVT_NO_BLOCKING_MODE_WIDTH 1
#define CCAM3_ATIS_CONTROL_IN_EVT_NO_BLOCKING_MODE_DEFAULT 0x00000001
#define CCAM3_ATIS_CONTROL_SISLEY_HVGA_REMAP_BYPASS_BIT_IDX 8
#define CCAM3_ATIS_CONTROL_SISLEY_HVGA_REMAP_BYPASS_WIDTH 1
#define CCAM3_ATIS_CONTROL_SISLEY_HVGA_REMAP_BYPASS_DEFAULT 0x00000001
#define CCAM3_ATIS_CONTROL_MASTER_MODE_BIT_IDX 12
#define CCAM3_ATIS_CONTROL_MASTER_MODE_WIDTH 1
#define CCAM3_ATIS_CONTROL_MASTER_MODE_DEFAULT 0x00000000
#define CCAM3_ATIS_CONTROL_MASTER_ENABLE_BIT_IDX 13
#define CCAM3_ATIS_CONTROL_MASTER_ENABLE_WIDTH 1
#define CCAM3_ATIS_CONTROL_MASTER_ENABLE_DEFAULT 0x00000000
#define CCAM3_ATIS_CONTROL_USE_EXT_START_BIT_IDX 14
#define CCAM3_ATIS_CONTROL_USE_EXT_START_WIDTH 1
#define CCAM3_ATIS_CONTROL_USE_EXT_START_DEFAULT 0x00000000
#define CCAM3_ATIS_CONTROL_ROI_TD_RSTN_BIT_IDX 18
#define CCAM3_ATIS_CONTROL_ROI_TD_RSTN_WIDTH 1
#define CCAM3_ATIS_CONTROL_ROI_TD_RSTN_DEFAULT 0x00000000
#define CCAM3_ATIS_CONTROL_EN_EXT_CTRL_RSTB_BIT_IDX 20
#define CCAM3_ATIS_CONTROL_EN_EXT_CTRL_RSTB_WIDTH 1
#define CCAM3_ATIS_CONTROL_EN_EXT_CTRL_RSTB_DEFAULT 0x00000000

#define CCAM3_ATIS_BIASROI_UPDATE_VALUE0_ADDR 0x00000002
#define CCAM3_ATIS_BIASROI_UPDATE_VALUE0_VALUE_BIT_IDX 0
#define CCAM3_ATIS_BIASROI_UPDATE_VALUE0_VALUE_WIDTH 16
#define CCAM3_ATIS_BIASROI_UPDATE_VALUE0_VALUE_DEFAULT 0x00000000

#define CCAM3_ATIS_BIASROI_UPDATE_VALUE1_ADDR 0x00000004
#define CCAM3_ATIS_BIASROI_UPDATE_VALUE1_VALUE_BIT_IDX 0
#define CCAM3_ATIS_BIASROI_UPDATE_VALUE1_VALUE_WIDTH 16
#define CCAM3_ATIS_BIASROI_UPDATE_VALUE1_VALUE_DEFAULT 0x00000000

#define CCAM3_ATIS_BIAS_UPDATE_VALUE2_ADDR 0x00000006
#define CCAM3_ATIS_BIAS_UPDATE_VALUE2_VALUE_BIT_IDX 0
#define CCAM3_ATIS_BIAS_UPDATE_VALUE2_VALUE_WIDTH 16
#define CCAM3_ATIS_BIAS_UPDATE_VALUE2_VALUE_DEFAULT 0x00000000

#define CCAM3_CCAM2_CONTROL_ADDR 0x00000008
#define CCAM3_CCAM2_CONTROL_ENABLE_64BITS_EVENT_BIT_IDX 3
#define CCAM3_CCAM2_CONTROL_ENABLE_64BITS_EVENT_WIDTH 1
#define CCAM3_CCAM2_CONTROL_ENABLE_64BITS_EVENT_DEFAULT 0x00000001
#define CCAM3_CCAM2_CONTROL_BYPASS_MAPPING_BIT_IDX 5
#define CCAM3_CCAM2_CONTROL_BYPASS_MAPPING_WIDTH 1
#define CCAM3_CCAM2_CONTROL_BYPASS_MAPPING_DEFAULT 0x00000001
#define CCAM3_CCAM2_CONTROL_HOST_IF_ENABLE_BIT_IDX 8
#define CCAM3_CCAM2_CONTROL_HOST_IF_ENABLE_WIDTH 1
#define CCAM3_CCAM2_CONTROL_HOST_IF_ENABLE_DEFAULT 0x00000000
#define CCAM3_CCAM2_CONTROL_STEREO_MERGE_ENABLE_BIT_IDX 9
#define CCAM3_CCAM2_CONTROL_STEREO_MERGE_ENABLE_WIDTH 1
#define CCAM3_CCAM2_CONTROL_STEREO_MERGE_ENABLE_DEFAULT 0x00000000
#define CCAM3_CCAM2_CONTROL_ENABLE_IMU_BIT_IDX 10
#define CCAM3_CCAM2_CONTROL_ENABLE_IMU_WIDTH 1
#define CCAM3_CCAM2_CONTROL_ENABLE_IMU_DEFAULT 0x00000000
#define CCAM3_CCAM2_CONTROL_ENABLE_OUT_OF_FOV_BIT_IDX 11
#define CCAM3_CCAM2_CONTROL_ENABLE_OUT_OF_FOV_WIDTH 1
#define CCAM3_CCAM2_CONTROL_ENABLE_OUT_OF_FOV_DEFAULT 0x00000000

#define CCAM3_TRIGGERS_ADDR 0x0000000A
#define CCAM3_TRIGGERS_SOFT_RESET_BIT_IDX 0
#define CCAM3_TRIGGERS_SOFT_RESET_WIDTH 1
#define CCAM3_TRIGGERS_SOFT_RESET_DEFAULT 0x00000000
#define CCAM3_TRIGGERS_BIAS_DIN_VALID_BIT_IDX 1
#define CCAM3_TRIGGERS_BIAS_DIN_VALID_WIDTH 1
#define CCAM3_TRIGGERS_BIAS_DIN_VALID_DEFAULT 0x00000000
#define CCAM3_TRIGGERS_TS_RESET_BIT_IDX 2
#define CCAM3_TRIGGERS_TS_RESET_WIDTH 1
#define CCAM3_TRIGGERS_TS_RESET_DEFAULT 0x00000000
#define CCAM3_TRIGGERS_ROI_DIN_BIT_IDX 3
#define CCAM3_TRIGGERS_ROI_DIN_WIDTH 1
#define CCAM3_TRIGGERS_ROI_DIN_DEFAULT 0x00000000
#define CCAM3_TRIGGERS_FIFO_RESET_BIT_IDX 7
#define CCAM3_TRIGGERS_FIFO_RESET_WIDTH 1
#define CCAM3_TRIGGERS_FIFO_RESET_DEFAULT 0x00000000
#define CCAM3_TRIGGERS_FLASH_ACCESS_BIT_IDX 8
#define CCAM3_TRIGGERS_FLASH_ACCESS_WIDTH 1
#define CCAM3_TRIGGERS_FLASH_ACCESS_DEFAULT 0x00000000
#define CCAM3_TRIGGERS_MAPPING_FETCH_BIT_IDX 9
#define CCAM3_TRIGGERS_MAPPING_FETCH_WIDTH 1
#define CCAM3_TRIGGERS_MAPPING_FETCH_DEFAULT 0x00000000
#define CCAM3_TRIGGERS_PROG_DAC_BIT_IDX 10
#define CCAM3_TRIGGERS_PROG_DAC_WIDTH 1
#define CCAM3_TRIGGERS_PROG_DAC_DEFAULT 0x00000000
#define CCAM3_TRIGGERS_DAC_DIN_VALID_BIT_IDX 11
#define CCAM3_TRIGGERS_DAC_DIN_VALID_WIDTH 1
#define CCAM3_TRIGGERS_DAC_DIN_VALID_DEFAULT 0x00000000

#define CCAM3_SYSTEM_STATUS_ADDR 0x0000000C
#define CCAM3_SYSTEM_STATUS_VALUE_BIT_IDX 0
#define CCAM3_SYSTEM_STATUS_VALUE_WIDTH 16
#define CCAM3_SYSTEM_STATUS_VALUE_DEFAULT 0x00000000

#define CCAM3_FOUT_LSB_STATUS_ADDR 0x0000000E
#define CCAM3_FOUT_LSB_STATUS_VALUE_BIT_IDX 0
#define CCAM3_FOUT_LSB_STATUS_VALUE_WIDTH 16
#define CCAM3_FOUT_LSB_STATUS_VALUE_DEFAULT 0x00000000

#define CCAM3_FOUT_MSB_STATUS_ADDR 0x00000010
#define CCAM3_FOUT_MSB_STATUS_VALUE_BIT_IDX 0
#define CCAM3_FOUT_MSB_STATUS_VALUE_WIDTH 16
#define CCAM3_FOUT_MSB_STATUS_VALUE_DEFAULT 0x00000000

#define CCAM3_FIFO_WRCOUNT_STATUS_ADDR 0x00000012
#define CCAM3_FIFO_WRCOUNT_STATUS_VALUE_BIT_IDX 0
#define CCAM3_FIFO_WRCOUNT_STATUS_VALUE_WIDTH 16
#define CCAM3_FIFO_WRCOUNT_STATUS_VALUE_DEFAULT 0x00000000

#define CCAM3_FIFO_CHECKPIX_STATUS_ADDR 0x00000014
#define CCAM3_FIFO_CHECKPIX_STATUS_VALUE_BIT_IDX 0
#define CCAM3_FIFO_CHECKPIX_STATUS_VALUE_WIDTH 16
#define CCAM3_FIFO_CHECKPIX_STATUS_VALUE_DEFAULT 0x00000000

#define CCAM3_TLAST_REARMUS_ADDR 0x00000016
#define CCAM3_TLAST_REARMUS_VALUE_BIT_IDX 0
#define CCAM3_TLAST_REARMUS_VALUE_WIDTH 16
#define CCAM3_TLAST_REARMUS_VALUE_DEFAULT 0x00000000

#define CCAM3_OVERFLOW_HITCOUNT_ADDR 0x00000018
#define CCAM3_OVERFLOW_HITCOUNT_VALUE_BIT_IDX 0
#define CCAM3_OVERFLOW_HITCOUNT_VALUE_WIDTH 16
#define CCAM3_OVERFLOW_HITCOUNT_VALUE_DEFAULT 0x00000000

#define CCAM3_CCAM2_MODE_ADDR 0x0000001A
#define CCAM3_CCAM2_MODE_VALUE_BIT_IDX 0
#define CCAM3_CCAM2_MODE_VALUE_WIDTH 16
#define CCAM3_CCAM2_MODE_VALUE_DEFAULT 0x00000000

#define CCAM3_SERIAL_LSB_ADDR 0x0000001C
#define CCAM3_SERIAL_LSB_VALUE_BIT_IDX 0
#define CCAM3_SERIAL_LSB_VALUE_WIDTH 16
#define CCAM3_SERIAL_LSB_VALUE_DEFAULT 0x00000000

#define CCAM3_SERIAL_MSB_ADDR 0x00000020
#define CCAM3_SERIAL_MSB_VALUE_BIT_IDX 0
#define CCAM3_SERIAL_MSB_VALUE_WIDTH 16
#define CCAM3_SERIAL_MSB_VALUE_DEFAULT 0x00000000

#define CCAM3_NOTIFY_PACKETCOUNT_ADDR 0x00000022
#define CCAM3_NOTIFY_PACKETCOUNT_VALUE_BIT_IDX 0
#define CCAM3_NOTIFY_PACKETCOUNT_VALUE_WIDTH 16
#define CCAM3_NOTIFY_PACKETCOUNT_VALUE_DEFAULT 0x00000000

#define CCAM3_SNFETCH_FADDR_LSB_ADDR 0x00000024
#define CCAM3_SNFETCH_FADDR_LSB_VALUE_BIT_IDX 0
#define CCAM3_SNFETCH_FADDR_LSB_VALUE_WIDTH 16
#define CCAM3_SNFETCH_FADDR_LSB_VALUE_DEFAULT 0x00000000

#define CCAM3_SNFETCH_FADDR_MSB_ADDR 0x00000026
#define CCAM3_SNFETCH_FADDR_MSB_VALUE_BIT_IDX 0
#define CCAM3_SNFETCH_FADDR_MSB_VALUE_WIDTH 16
#define CCAM3_SNFETCH_FADDR_MSB_VALUE_DEFAULT 0x00000000

#define CCAM3_SNFETCH_RDATA_LSB_ADDR 0x00000028
#define CCAM3_SNFETCH_RDATA_LSB_VALUE_BIT_IDX 0
#define CCAM3_SNFETCH_RDATA_LSB_VALUE_WIDTH 16
#define CCAM3_SNFETCH_RDATA_LSB_VALUE_DEFAULT 0x00000000

#define CCAM3_SNFETCH_RDATA_MSB_ADDR 0x0000002A
#define CCAM3_SNFETCH_RDATA_MSB_VALUE_BIT_IDX 0
#define CCAM3_SNFETCH_RDATA_MSB_VALUE_WIDTH 16
#define CCAM3_SNFETCH_RDATA_MSB_VALUE_DEFAULT 0x00000000

#define CCAM3_SNFETCH_READ_ITER_ADDR 0x0000002C
#define CCAM3_SNFETCH_READ_ITER_VALUE_BIT_IDX 0
#define CCAM3_SNFETCH_READ_ITER_VALUE_WIDTH 16
#define CCAM3_SNFETCH_READ_ITER_VALUE_DEFAULT 0x00000000

#define CCAM3_SNFETCH_TIME_COUNT_ADDR 0x0000002E
#define CCAM3_SNFETCH_TIME_COUNT_VALUE_BIT_IDX 0
#define CCAM3_SNFETCH_TIME_COUNT_VALUE_WIDTH 16
#define CCAM3_SNFETCH_TIME_COUNT_VALUE_DEFAULT 0x00000000

#define CCAM3_BIAS_LOAD_ITERATION_COUNT_ADDR 0x00000030
#define CCAM3_BIAS_LOAD_ITERATION_COUNT_VALUE_BIT_IDX 0
#define CCAM3_BIAS_LOAD_ITERATION_COUNT_VALUE_WIDTH 16
#define CCAM3_BIAS_LOAD_ITERATION_COUNT_VALUE_DEFAULT 0x00000000

#define CCAM3_FLASH_PROGRAM_SEL_SLAVE_ADDR 0x00000032
#define CCAM3_FLASH_PROGRAM_SEL_SLAVE_VALUE_BIT_IDX 0
#define CCAM3_FLASH_PROGRAM_SEL_SLAVE_VALUE_WIDTH 16
#define CCAM3_FLASH_PROGRAM_SEL_SLAVE_VALUE_DEFAULT 0x00000000
#define CCAM3_FLASH_PROGRAM_FX3_ACCESS_LOCKDOWN_VALUE_BIT_IDX 16
#define CCAM3_FLASH_PROGRAM_FX3_ACCESS_LOCKDOWN_VALUE_WIDTH 1
#define CCAM3_FLASH_PROGRAM_FX3_ACCESS_LOCKDOWN_VALUE_DEFAULT 0x1

#define CCAM3_OUT_OF_FOV_FILTER_WIDTH_ADDR 0x00000034
#define CCAM3_OUT_OF_FOV_FILTER_WIDTH_VALUE_BIT_IDX 0
#define CCAM3_OUT_OF_FOV_FILTER_WIDTH_VALUE_WIDTH 11
#define CCAM3_OUT_OF_FOV_FILTER_WIDTH_VALUE_DEFAULT 0x00000280

#define CCAM3_OUT_OF_FOV_FILTER_HEIGHT_ADDR 0x00000036
#define CCAM3_OUT_OF_FOV_FILTER_HEIGHT_VALUE_BIT_IDX 0
#define CCAM3_OUT_OF_FOV_FILTER_HEIGHT_VALUE_WIDTH 11
#define CCAM3_OUT_OF_FOV_FILTER_HEIGHT_VALUE_DEFAULT 0x000001E0

#define CCAM3_TEP_EVT_RATE_CONTROL_ENABLE_ADDR 0x00000038
#define CCAM3_TEP_EVT_RATE_CONTROL_ENABLE_VALUE_BIT_IDX 0
#define CCAM3_TEP_EVT_RATE_CONTROL_ENABLE_VALUE_WIDTH 16
#define CCAM3_TEP_EVT_RATE_CONTROL_ENABLE_VALUE_DEFAULT 0x00000000

#define CCAM3_TEP_EVT_RATE_CONTROL_T_DROP_FACTOR_ADDR 0x0000003A
#define CCAM3_TEP_EVT_RATE_CONTROL_T_DROP_FACTOR_VALUE_BIT_IDX 0
#define CCAM3_TEP_EVT_RATE_CONTROL_T_DROP_FACTOR_VALUE_WIDTH 16
#define CCAM3_TEP_EVT_RATE_CONTROL_T_DROP_FACTOR_VALUE_DEFAULT 0x00000000

#define CCAM3_EXT_SYNC_OUT_MODE_ADDR 0x0000003C
#define CCAM3_EXT_SYNC_OUT_MODE_VALUE_BIT_IDX 0 // Set to 1 to select the trigger out on the output multiplexer
#define CCAM3_EXT_SYNC_OUT_MODE_VALUE_WIDTH 1
#define CCAM3_EXT_SYNC_OUT_MODE_VALUE_DEFAULT 0x00000000

//------------------------------------------------------------------------------------------------------------
// CCAM3_SYSTEM_MONITOR
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SYSTEM_MONITOR_BASE_ADDR 0x00000040
#define CCAM3_SYSTEM_MONITOR_LAST_ADDR 0x000001AC
#define CCAM3_SYSTEM_MONITOR_SIZE 0x000001C0

//------------------------------------------------------------------------------------------------------------
// CCAM3_TEMP_VCC_MONITOR_XADC
//------------------------------------------------------------------------------------------------------------

#define CCAM3_TEMP_VCC_MONITOR_XADC_BASE_ADDR 0x00000040
#define CCAM3_TEMP_VCC_MONITOR_XADC_LAST_ADDR 0x000000FE
#define CCAM3_TEMP_VCC_MONITOR_XADC_SIZE 0x00000100

#define CCAM3_TEMP_VCC_MONITOR_XADC_TEMP_ADDR 0x00000040
#define CCAM3_TEMP_VCC_MONITOR_XADC_TEMP_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_TEMP_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_TEMP_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_INT_ADDR 0x00000042
#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_INT_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_INT_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_INT_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_AUX_ADDR 0x00000044
#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_AUX_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_AUX_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_AUX_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VP_VN_ADDR 0x00000046
#define CCAM3_TEMP_VCC_MONITOR_XADC_VP_VN_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VP_VN_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VP_VN_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VREFP_ADDR 0x00000048
#define CCAM3_TEMP_VCC_MONITOR_XADC_VREFP_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VREFP_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VREFP_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VREFN_ADDR 0x0000004A
#define CCAM3_TEMP_VCC_MONITOR_XADC_VREFN_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VREFN_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VREFN_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_BRAM_ADDR 0x0000004C
#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_BRAM_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_BRAM_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VCC_BRAM_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_SUPPLY_OFFSET_ADDR 0x00000050
#define CCAM3_TEMP_VCC_MONITOR_XADC_SUPPLY_OFFSET_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_SUPPLY_OFFSET_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_SUPPLY_OFFSET_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_OFFSET_ADDR 0x00000052
#define CCAM3_TEMP_VCC_MONITOR_XADC_OFFSET_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_OFFSET_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_OFFSET_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_GAIN_ERROR_ADDR 0x00000054
#define CCAM3_TEMP_VCC_MONITOR_XADC_GAIN_ERROR_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_GAIN_ERROR_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_GAIN_ERROR_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX0_ADDR 0x00000060
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX0_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX0_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX0_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX1_ADDR 0x00000062
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX1_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX1_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX1_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX2_ADDR 0x00000064
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX2_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX2_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX2_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX3_ADDR 0x00000066
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX3_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX3_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX3_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX4_ADDR 0x00000068
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX4_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX4_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX4_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX5_ADDR 0x0000006A
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX5_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX5_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX5_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX6_ADDR 0x0000006C
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX6_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX6_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX6_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX7_ADDR 0x0000006E
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX7_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX7_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX7_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX8_ADDR 0x00000070
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX8_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX8_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX8_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX9_ADDR 0x00000072
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX9_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX9_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX9_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX10_ADDR 0x00000074
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX10_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX10_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX10_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX11_ADDR 0x00000076
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX11_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX11_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX11_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX12_ADDR 0x00000078
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX12_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX12_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX12_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX13_ADDR 0x0000007A
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX13_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX13_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX13_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX14_ADDR 0x0000007C
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX14_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX14_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX14_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX15_ADDR 0x0000007E
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX15_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX15_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_VAUX15_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_TEMP_ADDR 0x00000080
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_TEMP_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_TEMP_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_TEMP_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_INT_ADDR 0x00000082
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_INT_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_INT_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_INT_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_AUX_ADDR 0x00000084
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_AUX_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_AUX_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_AUX_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_BRAM_ADDR 0x00000086
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_BRAM_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_BRAM_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_MAX_VCC_BRAM_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_TEMP_ADDR 0x00000088
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_TEMP_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_TEMP_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_TEMP_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_INT_ADDR 0x0000008A
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_INT_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_INT_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_INT_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_AUX_ADDR 0x0000008C
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_AUX_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_AUX_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_AUX_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_BRAM_ADDR 0x0000008E
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_BRAM_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_BRAM_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_MIN_VCC_BRAM_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_FLAGS_ADDR 0x000000BE
#define CCAM3_TEMP_VCC_MONITOR_XADC_FLAGS_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_FLAGS_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_FLAGS_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG0_ADDR 0x000000C0
#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG0_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG0_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG0_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG1_ADDR 0x000000C2
#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG1_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG1_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG1_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG2_ADDR 0x000000C4
#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG2_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG2_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_CONF_REG2_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG0_ADDR 0x000000D0
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG0_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG0_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG0_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG1_ADDR 0x000000D2
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG1_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG1_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG1_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG2_ADDR 0x000000D4
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG2_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG2_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG2_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG3_ADDR 0x000000D6
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG3_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG3_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG3_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG4_ADDR 0x000000D8
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG4_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG4_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG4_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG5_ADDR 0x000000DA
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG5_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG5_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG5_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG6_ADDR 0x000000DC
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG6_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG6_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG6_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG7_ADDR 0x000000DE
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG7_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG7_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_SEQ_REG7_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG0_ADDR 0x000000E0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG0_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG0_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG0_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG1_ADDR 0x000000E2
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG1_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG1_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG1_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG2_ADDR 0x000000E4
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG2_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG2_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG2_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG3_ADDR 0x000000E6
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG3_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG3_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG3_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG4_ADDR 0x000000E8
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG4_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG4_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG4_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG5_ADDR 0x000000EA
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG5_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG5_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG5_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG6_ADDR 0x000000EC
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG6_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG6_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG6_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG7_ADDR 0x000000EE
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG7_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG7_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG7_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG8_ADDR 0x000000F0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG8_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG8_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG8_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG9_ADDR 0x000000F2
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG9_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG9_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG9_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG10_ADDR 0x000000F4
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG10_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG10_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG10_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG11_ADDR 0x000000F6
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG11_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG11_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG11_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG12_ADDR 0x000000F8
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG12_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG12_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG12_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG13_ADDR 0x000000FA
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG13_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG13_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG13_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG14_ADDR 0x000000FC
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG14_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG14_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG14_VALUE_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG15_ADDR 0x000000FE
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG15_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG15_VALUE_WIDTH 16
#define CCAM3_TEMP_VCC_MONITOR_XADC_ALARM_THR_REG15_VALUE_DEFAULT 0x00000000

//------------------------------------------------------------------------------------------------------------
// CCAM3_TEMP_VCC_MONITOR
//------------------------------------------------------------------------------------------------------------

#define CCAM3_TEMP_VCC_MONITOR_BASE_ADDR 0x00000140
#define CCAM3_TEMP_VCC_MONITOR_LAST_ADDR 0x0000014C
#define CCAM3_TEMP_VCC_MONITOR_SIZE 0x00000020

#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_ADDR 0x00000140
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_ALL_EVT_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_ALL_EVT_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_ALL_EVT_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_TEMP_EVT_BIT_IDX 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_TEMP_EVT_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_TEMP_EVT_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_INT_EVT_BIT_IDX 2
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_INT_EVT_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_INT_EVT_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_AUX_EVT_BIT_IDX 3
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_AUX_EVT_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_AUX_EVT_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_BRAM_EVT_BIT_IDX 4
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_BRAM_EVT_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_BRAM_EVT_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_ALL_ALARM_BIT_IDX 8
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_ALL_ALARM_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_ALL_ALARM_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_OVER_TEMP_ALARM_BIT_IDX 9
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_OVER_TEMP_ALARM_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_OVER_TEMP_ALARM_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_USER_TEMP_ALARM_BIT_IDX 10
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_USER_TEMP_ALARM_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_USER_TEMP_ALARM_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_INT_ALARM_BIT_IDX 11
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_INT_ALARM_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_INT_ALARM_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_AUX_ALARM_BIT_IDX 12
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_AUX_ALARM_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_AUX_ALARM_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_BRAM_ALARM_BIT_IDX 13
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_BRAM_ALARM_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_VCC_BRAM_ALARM_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_SYSTEM_POWER_DOWN_BIT_IDX 16
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_SYSTEM_POWER_DOWN_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EVT_ENABLE_SYSTEM_POWER_DOWN_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_EVT_PERIOD_ADDR 0x00000144
#define CCAM3_TEMP_VCC_MONITOR_EVT_PERIOD_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_EVT_PERIOD_WIDTH 24
#define CCAM3_TEMP_VCC_MONITOR_EVT_PERIOD_DEFAULT 0x000186A0

#define CCAM3_TEMP_VCC_MONITOR_EXT_TEMP_CONTROL_ADDR 0x00000148
#define CCAM3_TEMP_VCC_MONITOR_EXT_TEMP_CONTROL_STATUS_SYS_POWER_DOWN_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_EXT_TEMP_CONTROL_STATUS_SYS_POWER_DOWN_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EXT_TEMP_CONTROL_STATUS_SYS_POWER_DOWN_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EXT_TEMP_CONTROL_EXT_TEMP_MONITOR_EN_BIT_IDX 1
#define CCAM3_TEMP_VCC_MONITOR_EXT_TEMP_CONTROL_EXT_TEMP_MONITOR_EN_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EXT_TEMP_CONTROL_EXT_TEMP_MONITOR_EN_DEFAULT 0x00000000
#define CCAM3_TEMP_VCC_MONITOR_EXT_TEMP_CONTROL_EXT_TEMP_MONITOR_SPI_EN_BIT_IDX 2
#define CCAM3_TEMP_VCC_MONITOR_EXT_TEMP_CONTROL_EXT_TEMP_MONITOR_SPI_EN_WIDTH 1
#define CCAM3_TEMP_VCC_MONITOR_EXT_TEMP_CONTROL_EXT_TEMP_MONITOR_SPI_EN_DEFAULT 0x00000000

#define CCAM3_TEMP_VCC_MONITOR_EVK_EXT_TEMP_VALUE_ADDR 0x0000014C
#define CCAM3_TEMP_VCC_MONITOR_EVK_EXT_TEMP_VALUE_BIT_IDX 0
#define CCAM3_TEMP_VCC_MONITOR_EVK_EXT_TEMP_VALUE_WIDTH 22
#define CCAM3_TEMP_VCC_MONITOR_EVK_EXT_TEMP_VALUE_DEFAULT 0x00000000

//------------------------------------------------------------------------------------------------------------
// CCAM3_ATIS_IF_MONITOR
//------------------------------------------------------------------------------------------------------------

#define CCAM3_ATIS_IF_MONITOR_BASE_ADDR 0x00000180
#define CCAM3_ATIS_IF_MONITOR_LAST_ADDR 0x0000018C
#define CCAM3_ATIS_IF_MONITOR_SIZE 0x00000020

#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_ADDR \
    0x00000180 // Controls the enable/disable of individual ATIS I/F Monitor's periodic events and alarms.
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_ALL_EVT_BIT_IDX 0
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_ALL_EVT_WIDTH 1
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_ALL_EVT_DEFAULT 0x00000000
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_TD_IDLE_TIME_EVT_BIT_IDX 1
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_TD_IDLE_TIME_EVT_WIDTH 1
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_TD_IDLE_TIME_EVT_DEFAULT 0x00000000
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_TD_IDLE_TIMEOUT_EVT_BIT_IDX 2
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_TD_IDLE_TIMEOUT_EVT_WIDTH 1
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_TD_IDLE_TIMEOUT_EVT_DEFAULT 0x00000000
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_APS_IDLE_TIME_EVT_BIT_IDX 3
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_APS_IDLE_TIME_EVT_WIDTH 1
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_APS_IDLE_TIME_EVT_DEFAULT 0x00000000
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_APS_IDLE_TIMEOUT_EVT_BIT_IDX 4
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_APS_IDLE_TIMEOUT_EVT_WIDTH 1
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_APS_IDLE_TIMEOUT_EVT_DEFAULT 0x00000000
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_GLOBAL_ILLUMINATION_EVT_BIT_IDX 5
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_GLOBAL_ILLUMINATION_EVT_WIDTH 1
#define CCAM3_ATIS_IF_MONITOR_CFG_ENABLE_GLOBAL_ILLUMINATION_EVT_DEFAULT 0x00000000

#define CCAM3_ATIS_IF_MONITOR_CFG_IDLE_TIME_THR_ADDR \
    0x00000184 // Sets the threshold time value in us after which {MASTER|SLAVE}_ATIS_{TD|APS}_IDLE_TIME events are
               // sent.  These events determine the amount of time between two consecutive events in the respective
               // channel if such time is above the threshold.
#define CCAM3_ATIS_IF_MONITOR_CFG_IDLE_TIME_THR_VALUE_BIT_IDX 0
#define CCAM3_ATIS_IF_MONITOR_CFG_IDLE_TIME_THR_VALUE_WIDTH 26
#define CCAM3_ATIS_IF_MONITOR_CFG_IDLE_TIME_THR_VALUE_DEFAULT 0x00002710

#define CCAM3_ATIS_IF_MONITOR_CFG_IDLE_TIMEOUT_THR_ADDR \
    0x00000188 // Sets the threshold time value in us after which {MASTER|SLAVE}_ATIS_{TD|APS}_IDLE_TIMEOUT events are
               // sent.  These events notify the host that the monitored channel has been inactive beyond this time
               // threshold.
#define CCAM3_ATIS_IF_MONITOR_CFG_IDLE_TIMEOUT_THR_VALUE_BIT_IDX 0
#define CCAM3_ATIS_IF_MONITOR_CFG_IDLE_TIMEOUT_THR_VALUE_WIDTH 26
#define CCAM3_ATIS_IF_MONITOR_CFG_IDLE_TIMEOUT_THR_VALUE_DEFAULT 0x00002710

#define CCAM3_ATIS_IF_MONITOR_STAT_GLOBAL_ILLUMINATION_ADDR 0x0000018C
#define CCAM3_ATIS_IF_MONITOR_STAT_GLOBAL_ILLUMINATION_DATA_BIT_IDX 0
#define CCAM3_ATIS_IF_MONITOR_STAT_GLOBAL_ILLUMINATION_DATA_WIDTH 26
#define CCAM3_ATIS_IF_MONITOR_STAT_GLOBAL_ILLUMINATION_DATA_DEFAULT 0x00000000
#define CCAM3_ATIS_IF_MONITOR_STAT_GLOBAL_ILLUMINATION_VALID_BIT_IDX 31
#define CCAM3_ATIS_IF_MONITOR_STAT_GLOBAL_ILLUMINATION_VALID_WIDTH 1
#define CCAM3_ATIS_IF_MONITOR_STAT_GLOBAL_ILLUMINATION_VALID_DEFAULT 0x00000000

//------------------------------------------------------------------------------------------------------------
// CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_BASE_ADDR 0x000001A0
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_LAST_ADDR 0x000001AC
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_SIZE 0x00000020

#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_ENABLE_ADDR 0x000001A0
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_ENABLE_VALUE_BIT_IDX 0
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_ENABLE_VALUE_WIDTH 1
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_ENABLE_VALUE_DEFAULT 0x00000000

#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_ENABLE_ADDR 0x000001A4
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_ENABLE_VALUE_BIT_IDX 0
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_ENABLE_VALUE_WIDTH 1
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_ENABLE_VALUE_DEFAULT 0x00000000

#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_PULSE_PERIOD_ADDR 0x000001A8
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_PULSE_PERIOD_BIT_IDX 0
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_PULSE_PERIOD_WIDTH 32
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_PULSE_PERIOD_DEFAULT 0x00000064

#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_PULSE_WIDTH_ADDR 0x000001AC
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_PULSE_WIDTH_BIT_IDX 0
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_PULSE_WIDTH_WIDTH 32
#define CCAM3_SYSTEM_MONITOR_EXT_TRIGGERS_OUT_PULSE_WIDTH_DEFAULT 0x00000001

//------------------------------------------------------------------------------------------------------------
// CCAM3_SENSOR_IF
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SENSOR_IF_BASE_ADDR 0x00000200
#define CCAM3_SENSOR_IF_LAST_ADDR 0x00000750
#define CCAM3_SENSOR_IF_SIZE 0x00000600

//------------------------------------------------------------------------------------------------------------
// CCAM3_SISLEY
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SISLEY_BASE_ADDR 0x00000200
#define CCAM3_SISLEY_LAST_ADDR 0x0000073C
#define CCAM3_SISLEY_SIZE 0x00000540

//------------------------------------------------------------------------------------------------------------
// SENSOR - Global CTRL
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_ADDR 0x00000200
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_TD_COUPLE_CTRL_BIT_IDX \
    0 // Enable ATIS em
      // 0: td events do not trigger em events
      // 1: td events trigger em events
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_TD_COUPLE_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_TD_COUPLE_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_SW_GLOBAL_EN_BIT_IDX \
    1 // Global enable for the analog. Used in glue logic with block level reset.
      // 0: hold analog in reset
      // 1: analog can be enabled
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_SW_GLOBAL_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_SW_GLOBAL_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_BYPASS_DIGITAL_READOUT_CTRL_BIT_IDX \
    2 // Enable the readout fast path to route async interface directly to the digital output:
      // 0: digital readout is functional
      // 1: digital readout is bypassed
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_BYPASS_DIGITAL_READOUT_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_BYPASS_DIGITAL_READOUT_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_BGEN_RST_BIT_IDX \
    3 // BIAS reset
      // 0: biases connected to their reset values
      // 1: biases connected to their bias generator
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_BGEN_RST_WIDTH 1
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_BGEN_RST_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_BGEN_EN_BIT_IDX \
    4 // BIAS enable
      // 0: disable PTAT of bias generators
      // 1: enable PTAT of bias generators
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_BGEN_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_BGEN_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_TOP_CLK_DIV_EN_BIT_IDX 5 // Enable the digital core clock frequency divider
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_TOP_CLK_DIV_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_TOP_CLK_DIV_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_TOP_CLK_DIV_FACTOR_BIT_IDX \
    6 // Devide frequency:
      // 1: 2-factor
      // 2: 4-factor
      // 4: 8-factor(these 3 bits are supposed to be one-hot (aka only one divider factor must be selected). If it's not
      // the case the lowest one wins)
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_TOP_CLK_DIV_FACTOR_WIDTH 3
#define CCAM3_SISLEY_SENSOR_GLOBAL_CTRL_TOP_CLK_DIV_FACTOR_DEFAULT 0x00000000

#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ADDR 0x00000204
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_EN_BIT_IDX \
    0 // Enable ROI EM
      // 0 : EM full array
      // 1 : EM ROI
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_EN_BIT_IDX \
    1 // Enable ROI TD
      // 0 : TD full array
      // 1 : TD ROI
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_SHUTTER_BIT_IDX 2 // 1: Resets the whole EM ROI X and Y arrays
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_SHUTTER_WIDTH 1
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_SHUTTER_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_RSTN_BIT_IDX 3 // 0: Resets the whole TD ROI X and Y arrays
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_RSTN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_RSTN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_SHADOW_TRIGGER_BIT_IDX \
    4 // Latch the configured ROI EM into the shadow register
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_SHADOW_TRIGGER_WIDTH 1
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_SHADOW_TRIGGER_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_SHADOW_TRIGGER_BIT_IDX \
    5 // Latch the configured ROI TD into the shadow register
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_SHADOW_TRIGGER_WIDTH 1
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_SHADOW_TRIGGER_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_RONI_EN_BIT_IDX \
    6 // The content of the roi register must be intepreted as RONI actually, RONI output is driven by the shadow
      // registers, while ROI output pins are reset  For now only roi_td_X shadow register is affected by this
      // modification
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_RONI_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_RONI_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_SCAN_EN_BIT_IDX \
    7 // Any modification applied to roi em register is directly forwarded to the corresponding shadow register
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_SCAN_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_EM_SCAN_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_SCAN_EN_BIT_IDX \
    8 // Any modification applied to roi td register is directly forwarded to the corresponding shadow register
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_SCAN_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_ROI_CTRL_ROI_TD_SCAN_EN_DEFAULT 0x00000000

#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_ADDR 0x00000208
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_DELAY_RSTN_BIT_IDX \
    0 // Resets tunable delay of the state machine
      // 1: functional | 0: reset
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_DELAY_RSTN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_DELAY_RSTN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INTERFACE_X_RSTN_BIT_IDX \
    1 // Resets X interface of the state machine
      // 1: functional | 0: reset
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INTERFACE_X_RSTN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INTERFACE_X_RSTN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_Y_RSTN_BIT_IDX \
    2 // Resets Y output latches td_y<9:0>
      // 1: functional | 0: reset
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_Y_RSTN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_Y_RSTN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACK_ARRAY_RSTN_BIT_IDX \
    3 // Resets array acknowledge of the state machine
      // 1: functional | 0: reset
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACK_ARRAY_RSTN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACK_ARRAY_RSTN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_CTRL_RSTN_BIT_IDX \
    4 // Resets control state machine
      // 1: functional | 0: reset
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_CTRL_RSTN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_CTRL_RSTN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_DUM_CONNECT_CTRL_BIT_IDX \
    5 // Connects dummy latch to req x or b
      // 0: disconnected | 1: connected
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_DUM_CONNECT_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_DUM_CONNECT_CTRL_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_DUM_RSTN_BIT_IDX \
    6 // Resets dummy latch
      // 1: functional | 0: reset
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_DUM_RSTN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_DUM_RSTN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_PIXEL_DUM_RSTN_BIT_IDX \
    7 // Resets dummy pixel
      // 1: functional | 0: reset
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_PIXEL_DUM_RSTN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_PIXEL_DUM_RSTN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INTERFACE_Y_RSTN_BIT_IDX \
    8 // Resets Y interface of the state machine
      // 1: functional | 0: rese
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INTERFACE_Y_RSTN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INTERFACE_Y_RSTN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_X_RSTN_BIT_IDX \
    9 // Resets X latches
      // 1: functional | 0: reset
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_X_RSTN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_LATCH_X_RSTN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_STAT_X_CTRL_BIT_IDX \
    10 // Activates X statitizers
       // 0: inverter
       // 1: statitizer
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_STAT_X_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_STAT_X_CTRL_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PUX_CTRL_BIT_IDX \
    11 // Activates X active pull-ups with drive strength 'bit'
       // 0: active pull drive 1 disabled
       // 1: active pull drive 1 enabled
       // bit11:+1 strength
       // bit12:+2 strength
       // bit13:+4 strength
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PUX_CTRL_WIDTH 3
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PUX_CTRL_DEFAULT 0x00000003
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_STAT_Y_CTRL_BIT_IDX 14 // Activates Y statitizers 0: inverter 1: statitizer
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_STAT_Y_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_STAT_Y_CTRL_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PUY_CTRL_BIT_IDX \
    15 // Activates Y active pull-ups 0: active pull disabled 1: active pull enabled
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PUY_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PUY_CTRL_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_PIPELINE_CTRL_BIT_IDX \
    16 // Activate row pipeline 0: pipeline disbaled 1: pipeline enabled
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_PIPELINE_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_PIPELINE_CTRL_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PDY_CTRL_BIT_IDX \
    17 // bit17 - 0: no act pull down on req y - strength 1
       // bit18 - 0: no act pull down on req y - strength 2
       // bit19 - 0: no act pull down on req y - strength 4
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PDY_CTRL_WIDTH 3
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PDY_CTRL_DEFAULT 0x00000003
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PDX_CTRL_BIT_IDX \
    20 // bit20 - 0: no act pull down on req x - strength 1
       // bit21 - 0: no act pull down on req x - strength 2
       // bit22 - 0: no act pull down on req x - strength 4
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PDX_CTRL_WIDTH 3
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_ACT_PDX_CTRL_DEFAULT 0x00000003
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_REQ_EM_CTRL_BIT_IDX 23 // 0: req x active high 1: req x active low
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_REQ_EM_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_REQ_EM_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_POL_EM_CTRL_BIT_IDX \
    24 // 0: 0 = on event | 1 = off event 1: 0 = off event | 0 = on event
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_POL_EM_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_POL_EM_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_ACK_EM_CTRL_BIT_IDX 25 // 0: ackb active low 1: ackb active high
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_ACK_EM_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_ACK_EM_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_REQ_TD_CTRL_BIT_IDX 26 // 0: req x active high 1: req x active low
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_REQ_TD_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_REQ_TD_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_POL_TD_CTRL_BIT_IDX \
    27 // 0: 0 = on event | 1 = off event 1: 0 = off event | 0 = on event
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_POL_TD_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_POL_TD_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_ACK_TD_CTRL_BIT_IDX 28 // 0: ackb active low 1: ackb active high
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_ACK_TD_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_READOUT_CTRL_RO_INV_ACK_TD_CTRL_DEFAULT 0x00000000

#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_ADDR 0x0000020C
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_SEL_TEST_PHOTODIODE_BIT_IDX \
    0 // Selects either test pixel with photodiode or test pixel with current input
      // 0: test pixel with current input | 1: test pixel with photodiode
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_SEL_TEST_PHOTODIODE_WIDTH 1
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_SEL_TEST_PHOTODIODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_BIT_IDX 1 // Test pixel control signal- Not used
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_WIDTH 1
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_TL_BIT_IDX 2 // Top-left test pixel control signal
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_TL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_TL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_TR_BIT_IDX 3 // Top-right test pixel control signal
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_TR_WIDTH 1
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_TR_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_BR_BIT_IDX 4 // Bottom right test pixel control signal
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_BR_WIDTH 1
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_BR_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_BL_BIT_IDX 5 // Bottom left test pixel control signal
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_BL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_DIODE_BL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_PHOTODIODE_EN_BIT_IDX \
    6 // Test pixel enable, see datasheet(11.1.2.4.1 - Table 2)
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_PHOTODIODE_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_PHOTODIODE_EN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_EN_BIT_IDX 7 // Test pixel enable, see datasheet(11.1.2.4.1 - Table 2)
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TP_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA1_BIT_IDX 8 // See datasheet(11.1.2.4.2 - Table 3)
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA1_WIDTH 4
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA1_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA2_BIT_IDX 12 // See datasheet(11.1.2.4.2 - Table 3)
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA2_WIDTH 4
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA2_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA3_BIT_IDX 16 // See datasheet(11.1.2.4.2 - Table 3)
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA3_WIDTH 4
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA3_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA4_BIT_IDX 20 // See datasheet(11.1.2.4.2 - Table 3)
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA4_WIDTH 4
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPA4_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPD1_BIT_IDX 24 // See datasheet(11.1.2.4.3 - Table 4 and Figure 10)
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPD1_WIDTH 4
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPD1_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPD2_BIT_IDX 28 // See datasheet(11.1.2.4.3 - Table 4 and Figure 10)
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPD2_WIDTH 4
#define CCAM3_SISLEY_SENSOR_TESTBUS_CTRL_TBUS_SEL_TPD2_DEFAULT 0x00000000

#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_ADDR 0x00000210
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_OUT_EN_BIT_IDX \
    0 // enable clk at the output of the sensor towards the external interface (not the digital digital)
      // 0: clk_out is active, tied to ground
      // 1: clk_out is active, always on as soon as there is clk_in available
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_OUT_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_OUT_EN_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_DIFF_HI_CM_CTRL_BIT_IDX \
    1 // Setting to accommodate high common mode value in differential mode (1.4 V)
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_DIFF_HI_CM_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_DIFF_HI_CM_CTRL_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_DIFF_IOUT_X2_CTRL_BIT_IDX \
    2 // Setting to boost output current in differential mode
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_DIFF_IOUT_X2_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_DIFF_IOUT_X2_CTRL_DEFAULT 0x00000001
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_DC_UP_CTRL_BIT_IDX \
    3 // Setting to shift up output voltage in differential mode
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_DC_UP_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_DC_UP_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_POLARITY_CTRL_BIT_IDX \
    4 // Swap polarity of clk_out
      // 0: clk_out = clk_int
      // 1: clk_out = not(clk_int)
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_POLARITY_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_CLK_POLARITY_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_STAT_REQ_X_CTRL_BIT_IDX \
    5 // 0: req x bus has no statitizer
      // 1: req x bus has a statitizer
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_STAT_REQ_X_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_STAT_REQ_X_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_STAT_POL_CTRL_BIT_IDX \
    6 // 0: polarity bus has no statitizer
      // 1: polarity bus has a statitizer
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_STAT_POL_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_STAT_POL_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_TD_REQ_LAT_CTRL_BIT_IDX \
    7 // add X ns delay to the td req
      // 0: no delay
      // 1: ~500 ps
      // 2: ~1 ns
      // 3: ~2 ns
      // 4: ~4 ns
      // 5: ~4.5 ns
      // 6: ~5 ns
      // 7: ~6 ns
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_TD_REQ_LAT_CTRL_WIDTH 3
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_TD_REQ_LAT_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_TD_ACK_LAT_CTRL_BIT_IDX \
    10 // add X ns delay to the td ack
       // 0: no delay
       // 1: ~500 ps
       // 2: ~1 ns
       // 3: ~2 ns
       // 4: ~4 ns
       // 5: ~4.5 ns
       // 6: ~5 ns
       // 7: ~6 ns
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_TD_ACK_LAT_CTRL_WIDTH 3
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_TD_ACK_LAT_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_EM_REQ_LAT_CTRL_BIT_IDX \
    13 // add X ns delay to the em req
       // 0: no delay
       // 1: ~500 ps
       // 2: ~1 ns
       // 3: ~2 ns
       // 4: ~4 ns
       // 5: ~4.5 ns
       // 6: ~5 ns
       // 7: ~6 ns
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_EM_REQ_LAT_CTRL_WIDTH 3
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_EM_REQ_LAT_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_EM_ACK_LAT_CTRL_BIT_IDX \
    16 // add X ns delay to the em ack
       // 0: no delay
       // 1: ~500 ps
       // 2: ~1 ns
       // 3: ~2 ns
       // 4: ~4 ns
       // 5: ~4.5 ns
       // 6: ~5 ns
       // 7: ~6 ns
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_EM_ACK_LAT_CTRL_WIDTH 3
#define CCAM3_SISLEY_SENSOR_CLKSYNC_CTRL_RO_EM_ACK_LAT_CTRL_DEFAULT 0x00000000

#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_ADDR 0x00000214
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_COUNTER_BIT_IDX \
    0 // Pulsewidth measured value:
      // Max illuminance measurement pulse = 5*E-01s, min Tclk = 1*E-08 gives a max counter of 5*E07
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_COUNTER_WIDTH 26
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_COUNTER_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_COUNTER_VALID_BIT_IDX 29 // Pulsewidth measured value is valid
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_COUNTER_VALID_WIDTH 1
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_COUNTER_VALID_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_CNT_EN_BIT_IDX 30 // Enable pulsewidth counter
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_CNT_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_CNT_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_EN_BIT_IDX \
    31 // Enable illuminance measurement
       // 0: photocurrent measurement inactive
       // 1: photocurrent measurement active
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_LIFO_CTRL_LIFO_EN_DEFAULT 0x00000000

#define CCAM3_SISLEY_SENSOR_CHIP_ID_ADDR 0x00000218
#define CCAM3_SISLEY_SENSOR_CHIP_ID_CHIP_ID_BIT_IDX 0
#define CCAM3_SISLEY_SENSOR_CHIP_ID_CHIP_ID_WIDTH 32
#define CCAM3_SISLEY_SENSOR_CHIP_ID_CHIP_ID_DEFAULT 0x90000402

#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_ADDR 0x0000021C
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RO_ADDR_Y_STAT_CTRL_BIT_IDX \
    0 // readout - 0: no statitizer en Y addresses | 1: statitizer on every Y addresses
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RO_ADDR_Y_STAT_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RO_ADDR_Y_STAT_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RO_ADDR_X_STAT_CTRL_BIT_IDX \
    1 // readout - 0: no statitizer en X addresses | 1: statitizer on every X addresses
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RO_ADDR_X_STAT_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RO_ADDR_X_STAT_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_CLK_OUT_LAT_CTRL_BIT_IDX \
    2 // Clk factory -
      // 00: delay = 0 ps
      // 01: delay = 500 ps
      // 10: delay = 1 ns
      // 11: delay = 2 ns
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_CLK_OUT_LAT_CTRL_WIDTH 2
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_CLK_OUT_LAT_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RFEED_D_CTRL_BIT_IDX \
    22 // digital biasgen -0: feedback loop of the output opamps are made of a capacitor
       // 1: feedback loop of the output opamps are made of a capacitor and a resistor in series
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RFEED_D_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RFEED_D_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RFEED_A_CTRL_BIT_IDX \
    23 // analog biasgen - 0: feedback loop of the output opamps are made of a capacitor
       // 1: feedback loop of the output opamps are made of a capacitor and a resistor in series
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RFEED_A_CTRL_WIDTH 1
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_RFEED_A_CTRL_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_TP_REFR_CLK_EN_BIT_IDX \
    24 // test pixel -0: refractory period clock is disabled | 1: refractory period clock is enabled
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_TP_REFR_CLK_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_TP_REFR_CLK_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_TP_DARK_EN_BIT_IDX \
    25 // test pixel -0: pr_out of dark pixel (covered by metal) is disabled | 1: pr_out of dark pixel (covered by
       // metal) is enabled
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_TP_DARK_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_TP_DARK_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_TP_QE_EN_BIT_IDX \
    26 // test pixel -0: 3T pixel for QE measurement is disabled | 1: 3T pixel for QE measurement is enabled
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_TP_QE_EN_WIDTH 1
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_TP_QE_EN_DEFAULT 0x00000000
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_B_TM_BIT_IDX 29 // CISC PCMs
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_B_TM_WIDTH 3
#define CCAM3_SISLEY_SENSOR_SPARE_CTRL_B_TM_DEFAULT 0x00000000

//------------------------------------------------------------------------------------------------------------
// SENSOR - BIAS GENERATOR(REGBANK)
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SISLEY_IBGEN_VECTOR_0_ADDR 0x00000300         //'Bias_latchout_or_pu'
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_0_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_1_ADDR 0x00000304         //'BIAS_REQX_OR_PU'
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_1_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_2_ADDR 0x00000308         //'BIAS_REQ_PUX'
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_2_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_3_ADDR 0x0000030C         //'BIAS_REQ_PUY'
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_3_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_4_ADDR 0x00000310         //'BIAS_DEL_REQX_OR'
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_4_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_5_ADDR 0x00000314         //'BIAS_SENDREQ_PDX'
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_5_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_6_ADDR 0x00000318         //'BIAS_SENDREQ_PDY'
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_6_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_7_ADDR 0x0000031C         //'BIAS_DEL_ACK_ARRAY'
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_7_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_8_ADDR 0x00000320         //'BIAS_DEL_TIMEOUT'
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_8_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_9_ADDR 0x00000324         //'BIAS_INV'
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_9_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_10_ADDR 0x00000328         //'BIAS_REFR'
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_10_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_11_ADDR 0x0000032C         //'BIAS_CLK'
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_11_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_18_ADDR 0x00000348         //'BIAS_CAS'
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_18_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_19_ADDR 0x0000034C         //'BIAS_DIFF_OFF'
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_19_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_20_ADDR 0x00000350         //'BIAS_DIFF_ON'
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_20_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_21_ADDR 0x00000354         //'BIAS_DIFF'
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_21_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_22_ADDR 0x00000358         //'BIAS_FO'
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_22_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_23_ADDR 0x0000035C         //'BIAS_PR'
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_23_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_24_ADDR 0x00000360         //'BIAS_BULK'
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_24_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_25_ADDR \
    0x00000364 //'VDD_HPF' - When a bias generator supplies vdd_hpf, it is also connected to the pad also called
               // vdd_hpf.
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_25_BIAS_PAD_ENABLE_DEFAULT 0x00000000

#define CCAM3_SISLEY_IBGEN_VECTOR_26_ADDR 0x00000368         //'BIAS_BUF'
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_VDAC_VAL_BIT_IDX 0 // Voltage DAC value coded on 8 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_VDAC_VAL_WIDTH 8
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_VDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_IDAC_VAL_BIT_IDX 8 // Current DAC value coded on 13 bits
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_IDAC_VAL_WIDTH 13
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_IDAC_VAL_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_INTERNAL_BUFFER_BIT_IDX 21 // Buffer value (coded on 6 bits)
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_INTERNAL_BUFFER_WIDTH 6
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_INTERNAL_BUFFER_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_TYPE_BIT_IDX \
    27 // Selects bias mode
       // 0: current DAC
       // 1: voltage DAC
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_TYPE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_MODE_BIT_IDX \
    28 // Selects bias mode
       // 0: cascode (shifts DC up for NMOS and down for PMOS)
       // 1: normal
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_MODE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_MODE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_POLARITY_BIT_IDX \
    29 // Bias polarity of internal buffer
       // 0: PMOS
       // 1: NMOS
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_POLARITY_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_ENABLE_BIT_IDX \
    30 // Enable for internal biasing
       // 0: bias generator disabled
       // 1: bias generator enabled
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_PAD_ENABLE_BIT_IDX \
    31 // Chip pad enable of the bias generator
       // 0: pad disconnected
       // 1: pad connected
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_PAD_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IBGEN_VECTOR_26_BIAS_PAD_ENABLE_DEFAULT 0x00000000

//------------------------------------------------------------------------------------------------------------
// SENSOR - TD ROI X
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SISLEY_ROI_TD_X_0_ADDR 0x00000400

#define CCAM3_SISLEY_ROI_TD_X_1_ADDR 0x00000404

#define CCAM3_SISLEY_ROI_TD_X_2_ADDR 0x00000408

#define CCAM3_SISLEY_ROI_TD_X_3_ADDR 0x0000040C

#define CCAM3_SISLEY_ROI_TD_X_4_ADDR 0x00000410

#define CCAM3_SISLEY_ROI_TD_X_5_ADDR 0x00000414

#define CCAM3_SISLEY_ROI_TD_X_6_ADDR 0x00000418

#define CCAM3_SISLEY_ROI_TD_X_7_ADDR 0x0000041C

#define CCAM3_SISLEY_ROI_TD_X_8_ADDR 0x00000420

#define CCAM3_SISLEY_ROI_TD_X_9_ADDR 0x00000424

#define CCAM3_SISLEY_ROI_TD_X_10_ADDR 0x00000428

#define CCAM3_SISLEY_ROI_TD_X_11_ADDR 0x0000042C

#define CCAM3_SISLEY_ROI_TD_X_12_ADDR 0x00000430

#define CCAM3_SISLEY_ROI_TD_X_13_ADDR 0x00000434

#define CCAM3_SISLEY_ROI_TD_X_14_ADDR 0x00000438

#define CCAM3_SISLEY_ROI_TD_X_15_ADDR 0x0000043C

#define CCAM3_SISLEY_ROI_TD_X_16_ADDR 0x00000440

#define CCAM3_SISLEY_ROI_TD_X_17_ADDR 0x00000444

#define CCAM3_SISLEY_ROI_TD_X_18_ADDR 0x00000448

#define CCAM3_SISLEY_ROI_TD_X_19_ADDR 0x0000044C

#define CCAM3_SISLEY_ROI_TD_X_20_ADDR 0x00000450

//------------------------------------------------------------------------------------------------------------
// SENSOR - EM ROI Y
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SISLEY_ROI_TD_Y_0_ADDR 0x00000500

#define CCAM3_SISLEY_ROI_TD_Y_1_ADDR 0x00000504

#define CCAM3_SISLEY_ROI_TD_Y_2_ADDR 0x00000508

#define CCAM3_SISLEY_ROI_TD_Y_3_ADDR 0x0000050C

#define CCAM3_SISLEY_ROI_TD_Y_4_ADDR 0x00000510

#define CCAM3_SISLEY_ROI_TD_Y_5_ADDR 0x00000514

#define CCAM3_SISLEY_ROI_TD_Y_6_ADDR 0x00000518

#define CCAM3_SISLEY_ROI_TD_Y_7_ADDR 0x0000051C

#define CCAM3_SISLEY_ROI_TD_Y_8_ADDR 0x00000520

#define CCAM3_SISLEY_ROI_TD_Y_9_ADDR 0x00000524

#define CCAM3_SISLEY_ROI_TD_Y_10_ADDR 0x00000528

#define CCAM3_SISLEY_ROI_TD_Y_11_ADDR 0x0000052C

#define CCAM3_SISLEY_ROI_TD_Y_12_ADDR 0x00000530

#define CCAM3_SISLEY_ROI_TD_Y_13_ADDR 0x00000534

#define CCAM3_SISLEY_ROI_TD_Y_14_ADDR 0x00000538

#define CCAM3_SISLEY_ROI_TD_Y_15_ADDR 0x0000053C

//------------------------------------------------------------------------------------------------------------
// SENSOR - EM ROI X
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SISLEY_ROI_EM_X_0_ADDR 0x00000600

#define CCAM3_SISLEY_ROI_EM_X_1_ADDR 0x00000604

#define CCAM3_SISLEY_ROI_EM_X_2_ADDR 0x00000608

#define CCAM3_SISLEY_ROI_EM_X_3_ADDR 0x0000060C

#define CCAM3_SISLEY_ROI_EM_X_4_ADDR 0x00000610

#define CCAM3_SISLEY_ROI_EM_X_5_ADDR 0x00000614

#define CCAM3_SISLEY_ROI_EM_X_6_ADDR 0x00000618

#define CCAM3_SISLEY_ROI_EM_X_7_ADDR 0x0000061C

#define CCAM3_SISLEY_ROI_EM_X_8_ADDR 0x00000620

#define CCAM3_SISLEY_ROI_EM_X_9_ADDR 0x00000624

#define CCAM3_SISLEY_ROI_EM_X_10_ADDR 0x00000628

#define CCAM3_SISLEY_ROI_EM_X_11_ADDR 0x0000062C

#define CCAM3_SISLEY_ROI_EM_X_12_ADDR 0x00000630

#define CCAM3_SISLEY_ROI_EM_X_13_ADDR 0x00000634

#define CCAM3_SISLEY_ROI_EM_X_14_ADDR 0x00000638

#define CCAM3_SISLEY_ROI_EM_X_15_ADDR 0x0000063C

#define CCAM3_SISLEY_ROI_EM_X_16_ADDR 0x00000640

#define CCAM3_SISLEY_ROI_EM_X_17_ADDR 0x00000644

#define CCAM3_SISLEY_ROI_EM_X_18_ADDR 0x00000648

#define CCAM3_SISLEY_ROI_EM_X_19_ADDR 0x0000064C

#define CCAM3_SISLEY_ROI_EM_X_20_ADDR 0x00000650

//------------------------------------------------------------------------------------------------------------
// SENSOR - EM ROI Y
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SISLEY_ROI_EM_Y_0_ADDR 0x00000700

#define CCAM3_SISLEY_ROI_EM_Y_1_ADDR 0x00000704

#define CCAM3_SISLEY_ROI_EM_Y_2_ADDR 0x00000708

#define CCAM3_SISLEY_ROI_EM_Y_3_ADDR 0x0000070C

#define CCAM3_SISLEY_ROI_EM_Y_4_ADDR 0x00000710

#define CCAM3_SISLEY_ROI_EM_Y_5_ADDR 0x00000714

#define CCAM3_SISLEY_ROI_EM_Y_6_ADDR 0x00000718

#define CCAM3_SISLEY_ROI_EM_Y_7_ADDR 0x0000071C

#define CCAM3_SISLEY_ROI_EM_Y_8_ADDR 0x00000720

#define CCAM3_SISLEY_ROI_EM_Y_9_ADDR 0x00000724

#define CCAM3_SISLEY_ROI_EM_Y_10_ADDR 0x00000728

#define CCAM3_SISLEY_ROI_EM_Y_11_ADDR 0x0000072C

#define CCAM3_SISLEY_ROI_EM_Y_12_ADDR 0x00000730

#define CCAM3_SISLEY_ROI_EM_Y_13_ADDR 0x00000734

#define CCAM3_SISLEY_ROI_EM_Y_14_ADDR 0x00000738

#define CCAM3_SISLEY_ROI_EM_Y_15_ADDR 0x0000073C

//------------------------------------------------------------------------------------------------------------
// CCAM3_SISLEY_IF
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SISLEY_IF_BASE_ADDR 0x00000740
#define CCAM3_SISLEY_IF_LAST_ADDR 0x00000750
#define CCAM3_SISLEY_IF_SIZE 0x000000C0

#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_ADDR 0x00000740
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_ENABLE_BIT_IDX 0
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_ENABLE_WIDTH 1
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_ENABLE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_TYPE_BIT_IDX 4
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_TYPE_WIDTH 1
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_PIXEL_TYPE_BIT_IDX 8
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_PIXEL_TYPE_WIDTH 1
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_PIXEL_TYPE_DEFAULT 0x00000000
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_PIXEL_POLARITY_BIT_IDX 12
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_PIXEL_POLARITY_WIDTH 1
#define CCAM3_SISLEY_IF_TEST_PATTERN_CONTROL_PIXEL_POLARITY_DEFAULT 0x00000000

#define CCAM3_SISLEY_IF_TEST_PATTERN_N_PERIOD_ADDR 0x00000744
#define CCAM3_SISLEY_IF_TEST_PATTERN_N_PERIOD_VALID_RATIO_BIT_IDX 0
#define CCAM3_SISLEY_IF_TEST_PATTERN_N_PERIOD_VALID_RATIO_WIDTH 10
#define CCAM3_SISLEY_IF_TEST_PATTERN_N_PERIOD_VALID_RATIO_DEFAULT 0x00000000
#define CCAM3_SISLEY_IF_TEST_PATTERN_N_PERIOD_LENGTH_BIT_IDX 16
#define CCAM3_SISLEY_IF_TEST_PATTERN_N_PERIOD_LENGTH_WIDTH 16
#define CCAM3_SISLEY_IF_TEST_PATTERN_N_PERIOD_LENGTH_DEFAULT 0x00000000

#define CCAM3_SISLEY_IF_TEST_PATTERN_P_PERIOD_ADDR 0x00000748
#define CCAM3_SISLEY_IF_TEST_PATTERN_P_PERIOD_VALID_RATIO_BIT_IDX 0
#define CCAM3_SISLEY_IF_TEST_PATTERN_P_PERIOD_VALID_RATIO_WIDTH 10
#define CCAM3_SISLEY_IF_TEST_PATTERN_P_PERIOD_VALID_RATIO_DEFAULT 0x00000000
#define CCAM3_SISLEY_IF_TEST_PATTERN_P_PERIOD_LENGTH_BIT_IDX 16
#define CCAM3_SISLEY_IF_TEST_PATTERN_P_PERIOD_LENGTH_WIDTH 16
#define CCAM3_SISLEY_IF_TEST_PATTERN_P_PERIOD_LENGTH_DEFAULT 0x00000000

#define CCAM3_SISLEY_IF_CONTROL_ADDR 0x0000074C
#define CCAM3_SISLEY_IF_CONTROL_SELF_ACK_BIT_IDX 0
#define CCAM3_SISLEY_IF_CONTROL_SELF_ACK_WIDTH 1
#define CCAM3_SISLEY_IF_CONTROL_SELF_ACK_DEFAULT 0x00000000
#define CCAM3_SISLEY_IF_CONTROL_SENSOR_CLK_EN_BIT_IDX 1
#define CCAM3_SISLEY_IF_CONTROL_SENSOR_CLK_EN_WIDTH 1
#define CCAM3_SISLEY_IF_CONTROL_SENSOR_CLK_EN_DEFAULT 0x00000001
#define CCAM3_SISLEY_IF_CONTROL_EM_RSTN_TRIGGER_EN_BIT_IDX 4
#define CCAM3_SISLEY_IF_CONTROL_EM_RSTN_TRIGGER_EN_WIDTH 1
#define CCAM3_SISLEY_IF_CONTROL_EM_RSTN_TRIGGER_EN_DEFAULT 0x00000000

#define CCAM3_SISLEY_IF_TRIGGERS_ADDR 0x00000750
#define CCAM3_SISLEY_IF_TRIGGERS_RESET_AFIFO_BIT_IDX 0
#define CCAM3_SISLEY_IF_TRIGGERS_RESET_AFIFO_WIDTH 1
#define CCAM3_SISLEY_IF_TRIGGERS_RESET_AFIFO_DEFAULT 0x00000000

//------------------------------------------------------------------------------------------------------------
// CCAM3_SYSTEM_CONFIG
//------------------------------------------------------------------------------------------------------------

#define CCAM3_SYSTEM_CONFIG_BASE_ADDR 0x00000800
#define CCAM3_SYSTEM_CONFIG_LAST_ADDR 0x0000080C
#define CCAM3_SYSTEM_CONFIG_SIZE 0x00000010

#define CCAM3_SYSTEM_CONFIG_ID_ADDR 0x00000800
#define CCAM3_SYSTEM_CONFIG_ID_BIT_IDX 0
#define CCAM3_SYSTEM_CONFIG_ID_WIDTH 8
#define CCAM3_SYSTEM_CONFIG_ID_DEFAULT 0x00000015

#define CCAM3_SYSTEM_CONFIG_VERSION_ADDR 0x00000804
#define CCAM3_SYSTEM_CONFIG_VERSION_MICRO_BIT_IDX 0
#define CCAM3_SYSTEM_CONFIG_VERSION_MICRO_WIDTH 8
#define CCAM3_SYSTEM_CONFIG_VERSION_MICRO_DEFAULT 0x00000000
#define CCAM3_SYSTEM_CONFIG_VERSION_MINOR_BIT_IDX 8
#define CCAM3_SYSTEM_CONFIG_VERSION_MINOR_WIDTH 8
#define CCAM3_SYSTEM_CONFIG_VERSION_MINOR_DEFAULT 0x00000000
#define CCAM3_SYSTEM_CONFIG_VERSION_MAJOR_BIT_IDX 16
#define CCAM3_SYSTEM_CONFIG_VERSION_MAJOR_WIDTH 8
#define CCAM3_SYSTEM_CONFIG_VERSION_MAJOR_DEFAULT 0x00000000

#define CCAM3_SYSTEM_CONFIG_BUILD_DATE_ADDR 0x00000808
#define CCAM3_SYSTEM_CONFIG_BUILD_DATE_BIT_IDX 0
#define CCAM3_SYSTEM_CONFIG_BUILD_DATE_WIDTH 32
#define CCAM3_SYSTEM_CONFIG_BUILD_DATE_DEFAULT 0x00000000

#define CCAM3_SYSTEM_CONFIG_VERSION_CONTROL_ID_ADDR 0x0000080C
#define CCAM3_SYSTEM_CONFIG_VERSION_CONTROL_ID_BIT_IDX 0
#define CCAM3_SYSTEM_CONFIG_VERSION_CONTROL_ID_WIDTH 32
#define CCAM3_SYSTEM_CONFIG_VERSION_CONTROL_ID_DEFAULT 0x00000000

//------------------------------------------------------------------------------------------------------------
// CCAM3_FX3_HOST_IF
//------------------------------------------------------------------------------------------------------------

#define CCAM3_FX3_HOST_IF_BASE_ADDR 0x00001400
#define CCAM3_FX3_HOST_IF_LAST_ADDR 0x00001408
#define CCAM3_FX3_HOST_IF_SIZE 0x00000100

#define CCAM3_FX3_HOST_IF_PKT_END_ENABLE_ADDR 0x00001400
#define CCAM3_FX3_HOST_IF_PKT_END_ENABLE_SHORT_PACKET_ENABLE_BIT_IDX 0
#define CCAM3_FX3_HOST_IF_PKT_END_ENABLE_SHORT_PACKET_ENABLE_WIDTH 1
#define CCAM3_FX3_HOST_IF_PKT_END_ENABLE_SHORT_PACKET_ENABLE_DEFAULT 0x00000001
#define CCAM3_FX3_HOST_IF_PKT_END_ENABLE_SHORT_PACKET_ENABLE_SKIP_BIT_IDX 1
#define CCAM3_FX3_HOST_IF_PKT_END_ENABLE_SHORT_PACKET_ENABLE_SKIP_WIDTH 1
#define CCAM3_FX3_HOST_IF_PKT_END_ENABLE_SHORT_PACKET_ENABLE_SKIP_DEFAULT 0x00000000

#define CCAM3_FX3_HOST_IF_PKT_END_INTERVAL_US_ADDR 0x00001404
#define CCAM3_FX3_HOST_IF_PKT_END_INTERVAL_US_BIT_IDX 0
#define CCAM3_FX3_HOST_IF_PKT_END_INTERVAL_US_WIDTH 32
#define CCAM3_FX3_HOST_IF_PKT_END_INTERVAL_US_DEFAULT 0x00000400

#define CCAM3_FX3_HOST_IF_PKT_END_DATA_COUNT_ADDR 0x00001408
#define CCAM3_FX3_HOST_IF_PKT_END_DATA_COUNT_BIT_IDX 0
#define CCAM3_FX3_HOST_IF_PKT_END_DATA_COUNT_WIDTH 32
#define CCAM3_FX3_HOST_IF_PKT_END_DATA_COUNT_DEFAULT 0x00000400

//------------------------------------------------------------------------------------------------------------
// CCAM3_IMU
//------------------------------------------------------------------------------------------------------------

#define CCAM3_IMU_BASE_ADDR 0x00001900
#define CCAM3_IMU_LAST_ADDR 0x00001975
#define CCAM3_IMU_SIZE 0x00000080

#define CCAM3_IMU_AX_MSB_ADDR 0x0000193B // IMU Accelerometer X-Axis MSB: AX[15:8]
#define CCAM3_IMU_AX_MSB_VALUE_BIT_IDX 0 // IMU Accelerometer X-Axis MSB: AX[15:8] value
#define CCAM3_IMU_AX_MSB_VALUE_WIDTH 8
#define CCAM3_IMU_AX_MSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_AX_LSB_ADDR 0x0000193C // IMU Accelerometer X-Axis LSB: AX[7:0]
#define CCAM3_IMU_AX_LSB_VALUE_BIT_IDX 0 // IMU Accelerometer X-Axis LSB: AX[7:0] value
#define CCAM3_IMU_AX_LSB_VALUE_WIDTH 8
#define CCAM3_IMU_AX_LSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_AY_MSB_ADDR 0x0000193D // IMU Accelerometer Y-Axis MSB: AY[15:8]
#define CCAM3_IMU_AY_MSB_VALUE_BIT_IDX 0 // IMU Accelerometer Y-Axis MSB: AY[15:8] value
#define CCAM3_IMU_AY_MSB_VALUE_WIDTH 8
#define CCAM3_IMU_AY_MSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_AY_LSB_ADDR 0x0000193E // IMU Accelerometer Y-Axis LSB: AY[7:0]
#define CCAM3_IMU_AY_LSB_VALUE_BIT_IDX 0 // IMU Accelerometer Y-Axis LSB: AY[7:0] value
#define CCAM3_IMU_AY_LSB_VALUE_WIDTH 8
#define CCAM3_IMU_AY_LSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_AZ_MSB_ADDR 0x0000193F // IMU Accelerometer Z-Axis MSB: AZ[15:8]
#define CCAM3_IMU_AZ_MSB_VALUE_BIT_IDX 0 // IMU Accelerometer Z-Axis MSB: AZ[15:8] value
#define CCAM3_IMU_AZ_MSB_VALUE_WIDTH 8
#define CCAM3_IMU_AZ_MSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_AZ_LSB_ADDR 0x00001940 // IMU Accelerometer Z-Axis LSB: AZ[7:0]
#define CCAM3_IMU_AZ_LSB_VALUE_BIT_IDX 0 // IMU Accelerometer Z-Axis LSB: AZ[7:0] value
#define CCAM3_IMU_AZ_LSB_VALUE_WIDTH 8
#define CCAM3_IMU_AZ_LSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_GX_MSB_ADDR 0x00001943 // IMU Gyroscope X-Axis MSB: GX[15:8]
#define CCAM3_IMU_GX_MSB_VALUE_BIT_IDX 0 // IMU Gyroscope X-Axis MSB: GX[15:8] value
#define CCAM3_IMU_GX_MSB_VALUE_WIDTH 8
#define CCAM3_IMU_GX_MSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_GX_LSB_ADDR 0x00001944 // IMU Gyroscope X-Axis LSB: GX[7:0]
#define CCAM3_IMU_GX_LSB_VALUE_BIT_IDX 0 // IMU Gyroscope X-Axis LSB: GX[7:0] value
#define CCAM3_IMU_GX_LSB_VALUE_WIDTH 8
#define CCAM3_IMU_GX_LSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_GY_MSB_ADDR 0x00001945 // IMU Gyroscope Y-Axis MSB: GY[15:8]
#define CCAM3_IMU_GY_MSB_VALUE_BIT_IDX 0 // IMU Gyroscope Y-Axis MSB: GY[15:8] value
#define CCAM3_IMU_GY_MSB_VALUE_WIDTH 8
#define CCAM3_IMU_GY_MSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_GY_LSB_ADDR 0x00001946 // IMU Gyroscope Y-Axis LSB: GY[7:0]
#define CCAM3_IMU_GY_LSB_VALUE_BIT_IDX 0 // IMU Gyroscope Y-Axis LSB: GY[7:0] value
#define CCAM3_IMU_GY_LSB_VALUE_WIDTH 8
#define CCAM3_IMU_GY_LSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_GZ_MSB_ADDR 0x00001947 // IMU Gyroscope Z-Axis MSB: GZ[15:8]
#define CCAM3_IMU_GZ_MSB_VALUE_BIT_IDX 0 // IMU Gyroscope Z-Axis MSB: GZ[15:8] value
#define CCAM3_IMU_GZ_MSB_VALUE_WIDTH 8
#define CCAM3_IMU_GZ_MSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_GZ_LSB_ADDR 0x00001948 // IMU Gyroscope Z-Axis LSB: GZ[7:0]
#define CCAM3_IMU_GZ_LSB_VALUE_BIT_IDX 0 // IMU Gyroscope Z-Axis LSB: GZ[7:0] value
#define CCAM3_IMU_GZ_LSB_VALUE_WIDTH 8
#define CCAM3_IMU_GZ_LSB_VALUE_DEFAULT 0x00000000

#define CCAM3_IMU_WHOAMI_ADDR 0x00001975 // IMU Who Am I
#define CCAM3_IMU_WHOAMI_VALUE_BIT_IDX 0 // IMU Who Am I value
#define CCAM3_IMU_WHOAMI_VALUE_WIDTH 8
#define CCAM3_IMU_WHOAMI_VALUE_DEFAULT 0x00000000

#endif // METAVISION_HAL_CCAM3_SINGLE_GEN3_H
